const webpack = require('webpack');
const path = require('path');

const paths = {
    DIST: path.resolve(__dirname, 'dist'),
    SRC: path.resolve(__dirname, 'src'),
};

const isProduction = process && process.env.NODE_ENV === 'production';
const plugins = [
    new webpack.DefinePlugin({
        'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV)
    })
];

if (isProduction) {
    plugins.push(
        new webpack.optimize.UglifyJsPlugin()
    );
}

module.exports = {
    entry: path.join(paths.SRC, 'lib.js'),
    output: {
        path: paths.DIST,
        filename: isProduction ? 'react-collaborative-codemirror.min.js' : 'react-collaborative-codemirror.js'
    },
    module: {
        rules: [{
            test: /\.(js|jsx)$/,
            exclude: /node_modules/,
            use: [
                'babel-loader',
            ]
        }]
    },
    plugins
};
